#[doc = r" Register block"]
#[repr(C)]
pub struct RegisterBlock {
    _reserved0: [u8; 8usize],
    #[doc = "0x08 - Synchronization Size Configuration Register"]
    pub sscr: SSCR,
    #[doc = "0x0c - Back Porch Configuration Register"]
    pub bpcr: BPCR,
    #[doc = "0x10 - Active Width Configuration Register"]
    pub awcr: AWCR,
    #[doc = "0x14 - Total Width Configuration Register"]
    pub twcr: TWCR,
    #[doc = "0x18 - Global Control Register"]
    pub gcr: GCR,
    _reserved1: [u8; 8usize],
    #[doc = "0x24 - Shadow Reload Configuration Register"]
    pub srcr: SRCR,
    _reserved2: [u8; 4usize],
    #[doc = "0x2c - Background Color Configuration Register"]
    pub bccr: BCCR,
    _reserved3: [u8; 4usize],
    #[doc = "0x34 - Interrupt Enable Register"]
    pub ier: IER,
    #[doc = "0x38 - Interrupt Status Register"]
    pub isr: ISR,
    #[doc = "0x3c - Interrupt Clear Register"]
    pub icr: ICR,
    #[doc = "0x40 - Line Interrupt Position Configuration Register"]
    pub lipcr: LIPCR,
    #[doc = "0x44 - Current Position Status Register"]
    pub cpsr: CPSR,
    #[doc = "0x48 - Current Display Status Register"]
    pub cdsr: CDSR,
    _reserved4: [u8; 56usize],
    #[doc = "0x84 - Cluster LAYER%s, containing L?CR, L?WHPCR, L?WVPCR, L?CKCR, L?PFCR, L?CACR, L?DCCR, L?BFCR, L?CFBAR, L?CFBLR, L?CFBLNR, L?CLUTWR"]
    pub layer1: LAYER,
    _reserved5: [u8; 60usize],
    #[doc = "0x104 - Cluster LAYER%s, containing L?CR, L?WHPCR, L?WVPCR, L?CKCR, L?PFCR, L?CACR, L?DCCR, L?BFCR, L?CFBAR, L?CFBLR, L?CFBLNR, L?CLUTWR"]
    pub layer2: LAYER,
}
#[doc = r" Register block"]
#[repr(C)]
pub struct LAYER {
    #[doc = "0x00 - Layerx Control Register"]
    pub cr: self::layer::CR,
    #[doc = "0x04 - Layerx Window Horizontal Position Configuration Register"]
    pub whpcr: self::layer::WHPCR,
    #[doc = "0x08 - Layerx Window Vertical Position Configuration Register"]
    pub wvpcr: self::layer::WVPCR,
    #[doc = "0x0c - Layerx Color Keying Configuration Register"]
    pub ckcr: self::layer::CKCR,
    #[doc = "0x10 - Layerx Pixel Format Configuration Register"]
    pub pfcr: self::layer::PFCR,
    #[doc = "0x14 - Layerx Constant Alpha Configuration Register"]
    pub cacr: self::layer::CACR,
    #[doc = "0x18 - Layerx Default Color Configuration Register"]
    pub dccr: self::layer::DCCR,
    #[doc = "0x1c - Layerx Blending Factors Configuration Register"]
    pub bfcr: self::layer::BFCR,
    _reserved0: [u8; 8usize],
    #[doc = "0x28 - Layerx Color Frame Buffer Address Register"]
    pub cfbar: self::layer::CFBAR,
    #[doc = "0x2c - Layerx Color Frame Buffer Length Register"]
    pub cfblr: self::layer::CFBLR,
    #[doc = "0x30 - Layerx ColorFrame Buffer Line Number Register"]
    pub cfblnr: self::layer::CFBLNR,
    _reserved1: [u8; 12usize],
    #[doc = "0x40 - Layerx CLUT Write Register"]
    pub clutwr: self::layer::CLUTWR,
}
#[doc = r" Register block"]
#[doc = "Cluster LAYER%s, containing L?CR, L?WHPCR, L?WVPCR, L?CKCR, L?PFCR, L?CACR, L?DCCR, L?BFCR, L?CFBAR, L?CFBLR, L?CFBLNR, L?CLUTWR"]
pub mod layer;
#[doc = "Synchronization Size Configuration Register"]
pub struct SSCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Synchronization Size Configuration Register"]
pub mod sscr;
#[doc = "Back Porch Configuration Register"]
pub struct BPCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Back Porch Configuration Register"]
pub mod bpcr;
#[doc = "Active Width Configuration Register"]
pub struct AWCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Active Width Configuration Register"]
pub mod awcr;
#[doc = "Total Width Configuration Register"]
pub struct TWCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Total Width Configuration Register"]
pub mod twcr;
#[doc = "Global Control Register"]
pub struct GCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Global Control Register"]
pub mod gcr;
#[doc = "Shadow Reload Configuration Register"]
pub struct SRCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Shadow Reload Configuration Register"]
pub mod srcr;
#[doc = "Background Color Configuration Register"]
pub struct BCCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Background Color Configuration Register"]
pub mod bccr;
#[doc = "Interrupt Enable Register"]
pub struct IER {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Interrupt Enable Register"]
pub mod ier;
#[doc = "Interrupt Status Register"]
pub struct ISR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Interrupt Status Register"]
pub mod isr;
#[doc = "Interrupt Clear Register"]
pub struct ICR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Interrupt Clear Register"]
pub mod icr;
#[doc = "Line Interrupt Position Configuration Register"]
pub struct LIPCR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Line Interrupt Position Configuration Register"]
pub mod lipcr;
#[doc = "Current Position Status Register"]
pub struct CPSR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Current Position Status Register"]
pub mod cpsr;
#[doc = "Current Display Status Register"]
pub struct CDSR {
    register: ::vcell::VolatileCell<u32>,
}
#[doc = "Current Display Status Register"]
pub mod cdsr;
